@@ -57,27 +57,41 @@ class Classifier(Model):
     
 
     # basic classifier
-    def classify(self,y_col_name,standardize=True,leave_one_out=False,n_splits=5,zscore_axis=0,C=None,resample=True,fillna=0):
+    def classify(self,
+                 y_col_name,
+                 standardize=True,
+                 leave_one_out=False,
+                 n_splits=5,
+                 zscore_axis=0,
+                 C=None,
+                 resample=True,
+                 fillna=0):
         loo=LeaveOneOut()
         kf = KFold(n_splits=n_splits,shuffle=True,random_state=11)
         all_predictions=[]
         all_probs=[]
         ind2prob={}
         ind2pred={}
-
         if resample:
-            Xdf=self.resample(y_col_name) #,standardize=standardize,zscore_axis=zscore_axis)
+            groups=self.df.groupby(y_col_name)
+            minsize=min(len(g) for i,g in groups)
+            Xdf=groups.sample(n=minsize)
         else:
             Xdf=self.df
 
         y=np.array(Xdf[y_col_name].apply(str)) # fix?
-        Xdfq=Xdf.select_dtypes('number').dropna(axis=0) #1)
+        Xdfq=Xdf.select_dtypes('number').dropna(axis=1) #1)
         
 
         if standardize:
-            Xdfq=Xdfq.apply(lambda col: (col - col.dropna().mean()) / col.dropna().std(), axis=0)
-            Xdfq=Xdf.select_dtypes('number').dropna(axis=0)
+            for col in Xdfq: Xdfq[col]=(Xdfq[col] - Xdfq[col].mean()) / Xdfq[col].std()
+
         X=Xdfq.values
+#         print(self.df.shape,'-->',Xdf.shape,'-->',Xdfq.shape)
+        Xdf=Xdf.loc[Xdfq.index]
+#         print(Xdfq.shape)
+        #display(Xdfq)
+        #display(Xdfq.iloc[0])
 
         self.Xdf=Xdf
         self.Xdfq=Xdfq
@@ -85,32 +99,14 @@ class Classifier(Model):
         self.y=y
 
         self.cols=cols=Xdf.columns
-
-        from collections import defaultdict
         all_coeffs=defaultdict(list)
         splitter = loo.split(X) if leave_one_out else kf.split(X)
 
         for train_index,test_index in splitter:
-#             print(train_index)
-#             print(test_index)
-            # build new model
             clf=self.get_clf()
-            # slice
-            #X_train, X_test = X[train_index], X[test_index]
             y_train, y_test = y[train_index], y[test_index]
             Xdf_train, Xdf_test = Xdfq.iloc[train_index], Xdfq.iloc[test_index]
-#             display(Xdf_train)
-#             display(Xdf_test)
-#             display(y_train)
-#             display(y_test)
             X_train,X_test = Xdf_train.values.astype('float'), Xdf_test.values.astype('float')
-#             # fit
-# #             print(type(X_train), type(X_test))
-# #             print(set(type(x) for x in X_train))
-#             print(set(type(y) for x in X_train for y in x))
-# #             print(set(type(x) for x in X_test))
-#             print(set(type(y) for x in X_test for y in x))
-            
             try:
                 clf.fit(X_train,y_train)
             except Exception as e:
@@ -118,9 +114,6 @@ class Classifier(Model):
                 continue
             probs=clf.predict_proba(X_test)
             predictions=clf.predict(X_test)
-#             print('DONE!',probs,predictions)
-            #return clf,probs,predictions
-
             if leave_one_out:
                 # predict probs
                 prob=probs[0][1]
@@ -153,9 +146,9 @@ class Classifier(Model):
         self.dfr=pd.DataFrame(index=Xdfq.index)
         self.dfr['pred']=all_predictions
         self.dfr['prob']=all_probs
-        self.dfr['true']=y
+        self.dfr['true']=self.dfr.join(Xdf[y_col_name])[y_col_name]
         self.dfr['correct']=[int(xx==yy) for xx,yy in zip(self.dfr.pred, self.dfr.true)]
-        self.dfr['support']=len(y)
+        self.dfr['support']=len(Xdfq)
         self.coeffs=all_coeffs
         self.dfc=pd.DataFrame([{'feat':c, 'coeff':f} for c,f in list(all_coeffs.items())])
         self.clf=clf
